pub enum TabDropZone {
TabBar(LeafId, Option<usize>),
SplitLeft(LeafId),
SplitRight(LeafId),
SplitTop(LeafId),
SplitBottom(LeafId),
SplitCenter(LeafId),
}Expand description
Drop zone for tab drag-and-drop Indicates where a dragged tab will be placed when released
Variants
TabBar(LeafId, Option<usize>)
Drop into an existing split’s tab bar (before tab at index, or at end if None) (target_split_id, insert_index)
SplitLeft(LeafId)
Create a new split on the left edge of the target split
SplitRight(LeafId)
Create a new split on the right edge of the target split
SplitTop(LeafId)
Create a new split on the top edge of the target split
SplitBottom(LeafId)
Create a new split on the bottom edge of the target split
SplitCenter(LeafId)
Drop into the center of a split (switch to that split’s tab bar)
Implementations