pub enum Action {
Show 291 variants
InsertChar(char),
InsertNewline,
InsertTab,
MoveLeft,
MoveRight,
MoveUp,
MoveDown,
MoveWordLeft,
MoveWordRight,
MoveWordEnd,
ViMoveWordEnd,
MoveLeftInLine,
MoveRightInLine,
MoveLineStart,
MoveLineEnd,
MoveLineUp,
MoveLineDown,
MovePageUp,
MovePageDown,
MoveDocumentStart,
MoveDocumentEnd,
SelectLeft,
SelectRight,
SelectUp,
SelectDown,
SelectToParagraphUp,
SelectToParagraphDown,
SelectWordLeft,
SelectWordRight,
SelectWordEnd,
ViSelectWordEnd,
SelectLineStart,
SelectLineEnd,
SelectDocumentStart,
SelectDocumentEnd,
SelectPageUp,
SelectPageDown,
SelectAll,
SelectWord,
SelectLine,
ExpandSelection,
BlockSelectLeft,
BlockSelectRight,
BlockSelectUp,
BlockSelectDown,
DeleteBackward,
DeleteForward,
DeleteWordBackward,
DeleteWordForward,
DeleteLine,
DeleteToLineEnd,
DeleteToLineStart,
DeleteViWordEnd,
TransposeChars,
OpenLine,
DuplicateLine,
Recenter,
SetMark,
Copy,
CopyWithTheme(String),
Cut,
Paste,
YankWordForward,
YankWordBackward,
YankToLineEnd,
YankToLineStart,
YankViWordEnd,
AddCursorAbove,
AddCursorBelow,
AddCursorNextMatch,
RemoveSecondaryCursors,
Save,
SaveAs,
Open,
SwitchProject,
New,
Close,
CloseTab,
Quit,
ForceQuit,
Detach,
Revert,
ToggleAutoRevert,
FormatBuffer,
TrimTrailingWhitespace,
EnsureFinalNewline,
GotoLine,
ScanLineIndex,
GoToMatchingBracket,
JumpToNextError,
JumpToPreviousError,
SmartHome,
DedentSelection,
ToggleComment,
DabbrevExpand,
ToggleFold,
SetBookmark(char),
JumpToBookmark(char),
ClearBookmark(char),
ListBookmarks,
ToggleSearchCaseSensitive,
ToggleSearchWholeWord,
ToggleSearchRegex,
ToggleSearchConfirmEach,
StartMacroRecording,
StopMacroRecording,
PlayMacro(char),
ToggleMacroRecording(char),
ShowMacro(char),
ListMacros,
PromptRecordMacro,
PromptPlayMacro,
PlayLastMacro,
PromptSetBookmark,
PromptJumpToBookmark,
Undo,
Redo,
ScrollUp,
ScrollDown,
ShowHelp,
ShowKeyboardShortcuts,
ShowWarnings,
ShowStatusLog,
ShowLspStatus,
ClearWarnings,
CommandPalette,
QuickOpen,
ToggleLineWrap,
ToggleCurrentLineHighlight,
ToggleReadOnly,
TogglePageView,
SetPageWidth,
InspectThemeAtCursor,
SelectTheme,
SelectKeybindingMap,
SelectCursorStyle,
SelectLocale,
NextBuffer,
PrevBuffer,
SwitchToPreviousTab,
SwitchToTabByName,
ScrollTabsLeft,
ScrollTabsRight,
NavigateBack,
NavigateForward,
SplitHorizontal,
SplitVertical,
CloseSplit,
NextSplit,
PrevSplit,
IncreaseSplitSize,
DecreaseSplitSize,
ToggleMaximizeSplit,
PromptConfirm,
PromptConfirmWithText(String),
PromptCancel,
PromptBackspace,
PromptDelete,
PromptMoveLeft,
PromptMoveRight,
PromptMoveStart,
PromptMoveEnd,
PromptSelectPrev,
PromptSelectNext,
PromptPageUp,
PromptPageDown,
PromptAcceptSuggestion,
PromptMoveWordLeft,
PromptMoveWordRight,
PromptDeleteWordForward,
PromptDeleteWordBackward,
PromptDeleteToLineEnd,
PromptCopy,
PromptCut,
PromptPaste,
PromptMoveLeftSelecting,
PromptMoveRightSelecting,
PromptMoveHomeSelecting,
PromptMoveEndSelecting,
PromptSelectWordLeft,
PromptSelectWordRight,
PromptSelectAll,
FileBrowserToggleHidden,
FileBrowserToggleDetectEncoding,
PopupSelectNext,
PopupSelectPrev,
PopupPageUp,
PopupPageDown,
PopupConfirm,
PopupCancel,
ToggleFileExplorer,
ToggleMenuBar,
ToggleTabBar,
ToggleStatusBar,
TogglePromptLine,
ToggleVerticalScrollbar,
ToggleHorizontalScrollbar,
FocusFileExplorer,
FocusEditor,
FileExplorerUp,
FileExplorerDown,
FileExplorerPageUp,
FileExplorerPageDown,
FileExplorerExpand,
FileExplorerCollapse,
FileExplorerOpen,
FileExplorerRefresh,
FileExplorerNewFile,
FileExplorerNewDirectory,
FileExplorerDelete,
FileExplorerRename,
FileExplorerToggleHidden,
FileExplorerToggleGitignored,
FileExplorerSearchClear,
FileExplorerSearchBackspace,
LspCompletion,
LspGotoDefinition,
LspReferences,
LspRename,
LspHover,
LspSignatureHelp,
LspCodeActions,
LspRestart,
LspStop,
LspToggleForBuffer,
ToggleInlayHints,
ToggleMouseHover,
ToggleLineNumbers,
ToggleScrollSync,
ToggleMouseCapture,
ToggleDebugHighlights,
SetBackground,
SetBackgroundBlend,
SetTabSize,
SetLineEnding,
SetEncoding,
ReloadWithEncoding,
SetLanguage,
ToggleIndentationStyle,
ToggleTabIndicators,
ToggleWhitespaceIndicators,
ResetBufferSettings,
AddRuler,
RemoveRuler,
DumpConfig,
Search,
FindInSelection,
FindNext,
FindPrevious,
FindSelectionNext,
FindSelectionPrevious,
Replace,
QueryReplace,
MenuActivate,
MenuClose,
MenuLeft,
MenuRight,
MenuUp,
MenuDown,
MenuExecute,
MenuOpen(String),
SwitchKeybindingMap(String),
PluginAction(String),
OpenSettings,
CloseSettings,
SettingsSave,
SettingsReset,
SettingsToggleFocus,
SettingsActivate,
SettingsSearch,
SettingsHelp,
SettingsIncrement,
SettingsDecrement,
SettingsInherit,
OpenTerminal,
CloseTerminal,
FocusTerminal,
TerminalEscape,
ToggleKeyboardCapture,
TerminalPaste,
ShellCommand,
ShellCommandReplace,
ToUpperCase,
ToLowerCase,
ToggleCase,
SortLines,
CalibrateInput,
EventDebug,
OpenKeybindingEditor,
LoadPluginFromBuffer,
None,
}Expand description
High-level actions that can be performed in the editor
Variants
InsertChar(char)
InsertNewline
InsertTab
MoveLeft
MoveRight
MoveUp
MoveDown
MoveWordLeft
MoveWordRight
MoveWordEnd
ViMoveWordEnd
MoveLeftInLine
MoveRightInLine
MoveLineStart
MoveLineEnd
MoveLineUp
MoveLineDown
MovePageUp
MovePageDown
MoveDocumentStart
MoveDocumentEnd
SelectLeft
SelectRight
SelectUp
SelectDown
SelectToParagraphUp
SelectToParagraphDown
SelectWordLeft
SelectWordRight
SelectWordEnd
ViSelectWordEnd
SelectLineStart
SelectLineEnd
SelectDocumentStart
SelectDocumentEnd
SelectPageUp
SelectPageDown
SelectAll
SelectWord
SelectLine
ExpandSelection
BlockSelectLeft
BlockSelectRight
BlockSelectUp
BlockSelectDown
DeleteBackward
DeleteForward
DeleteWordBackward
DeleteWordForward
DeleteLine
DeleteToLineEnd
DeleteToLineStart
DeleteViWordEnd
TransposeChars
OpenLine
DuplicateLine
Recenter
SetMark
Copy
CopyWithTheme(String)
Cut
Paste
YankWordForward
YankWordBackward
YankToLineEnd
YankToLineStart
YankViWordEnd
AddCursorAbove
AddCursorBelow
AddCursorNextMatch
RemoveSecondaryCursors
Save
SaveAs
Open
SwitchProject
New
Close
CloseTab
Quit
ForceQuit
Detach
Revert
ToggleAutoRevert
FormatBuffer
TrimTrailingWhitespace
EnsureFinalNewline
GotoLine
ScanLineIndex
GoToMatchingBracket
JumpToNextError
JumpToPreviousError
SmartHome
DedentSelection
ToggleComment
DabbrevExpand
ToggleFold
SetBookmark(char)
JumpToBookmark(char)
ClearBookmark(char)
ListBookmarks
ToggleSearchCaseSensitive
ToggleSearchWholeWord
ToggleSearchRegex
ToggleSearchConfirmEach
StartMacroRecording
StopMacroRecording
PlayMacro(char)
ToggleMacroRecording(char)
ShowMacro(char)
ListMacros
PromptRecordMacro
PromptPlayMacro
PlayLastMacro
PromptSetBookmark
PromptJumpToBookmark
Undo
Redo
ScrollUp
ScrollDown
ShowHelp
ShowKeyboardShortcuts
ShowWarnings
ShowStatusLog
ShowLspStatus
ClearWarnings
CommandPalette
QuickOpen
Quick Open - unified prompt with prefix-based provider routing
ToggleLineWrap
ToggleCurrentLineHighlight
ToggleReadOnly
TogglePageView
SetPageWidth
InspectThemeAtCursor
SelectTheme
SelectKeybindingMap
SelectCursorStyle
SelectLocale
NextBuffer
PrevBuffer
SwitchToPreviousTab
SwitchToTabByName
ScrollTabsLeft
ScrollTabsRight
SplitHorizontal
SplitVertical
CloseSplit
NextSplit
PrevSplit
IncreaseSplitSize
DecreaseSplitSize
ToggleMaximizeSplit
PromptConfirm
PromptConfirmWithText(String)
PromptConfirm with recorded text for macro playback
PromptCancel
PromptBackspace
PromptDelete
PromptMoveLeft
PromptMoveRight
PromptMoveStart
PromptMoveEnd
PromptSelectPrev
PromptSelectNext
PromptPageUp
PromptPageDown
PromptAcceptSuggestion
PromptMoveWordLeft
PromptMoveWordRight
PromptDeleteWordForward
PromptDeleteWordBackward
PromptDeleteToLineEnd
PromptCopy
PromptCut
PromptPaste
PromptMoveLeftSelecting
PromptMoveRightSelecting
PromptMoveHomeSelecting
PromptMoveEndSelecting
PromptSelectWordLeft
PromptSelectWordRight
PromptSelectAll
FileBrowserToggleHidden
FileBrowserToggleDetectEncoding
PopupSelectNext
PopupSelectPrev
PopupPageUp
PopupPageDown
PopupConfirm
PopupCancel
ToggleFileExplorer
ToggleMenuBar
ToggleTabBar
ToggleStatusBar
TogglePromptLine
ToggleVerticalScrollbar
ToggleHorizontalScrollbar
FocusFileExplorer
FocusEditor
FileExplorerUp
FileExplorerDown
FileExplorerPageUp
FileExplorerPageDown
FileExplorerExpand
FileExplorerCollapse
FileExplorerOpen
FileExplorerRefresh
FileExplorerNewFile
FileExplorerNewDirectory
FileExplorerDelete
FileExplorerRename
FileExplorerToggleHidden
FileExplorerToggleGitignored
FileExplorerSearchClear
FileExplorerSearchBackspace
LspCompletion
LspGotoDefinition
LspReferences
LspRename
LspHover
LspSignatureHelp
LspCodeActions
LspRestart
LspStop
LspToggleForBuffer
ToggleInlayHints
ToggleMouseHover
ToggleLineNumbers
ToggleScrollSync
ToggleMouseCapture
ToggleDebugHighlights
SetBackground
SetBackgroundBlend
SetTabSize
SetLineEnding
SetEncoding
ReloadWithEncoding
SetLanguage
ToggleIndentationStyle
ToggleTabIndicators
ToggleWhitespaceIndicators
ResetBufferSettings
AddRuler
RemoveRuler
DumpConfig
Search
FindInSelection
FindNext
FindPrevious
FindSelectionNext
FindSelectionPrevious
Replace
QueryReplace
MenuActivate
MenuClose
MenuLeft
MenuRight
MenuUp
MenuDown
MenuExecute
MenuOpen(String)
SwitchKeybindingMap(String)
PluginAction(String)
OpenSettings
CloseSettings
SettingsSave
SettingsReset
SettingsToggleFocus
SettingsActivate
SettingsSearch
SettingsHelp
SettingsIncrement
SettingsDecrement
SettingsInherit
OpenTerminal
CloseTerminal
FocusTerminal
TerminalEscape
ToggleKeyboardCapture
TerminalPaste
ShellCommand
ShellCommandReplace
ToUpperCase
ToLowerCase
ToggleCase
SortLines
CalibrateInput
EventDebug
OpenKeybindingEditor
LoadPluginFromBuffer
None
Implementations
Sourceimpl Action
impl Action
Sourcepub fn from_str(s: &str, args: &HashMap<String, Value>) -> Option<Self>
pub fn from_str(s: &str, args: &HashMap<String, Value>) -> Option<Self>
Parse action from string (used when loading from config)
Sourcepub fn to_action_str(&self) -> String
pub fn to_action_str(&self) -> String
Convert an action back to its string name (inverse of from_str). Returns the canonical action name string.
Sourcepub fn all_action_names() -> Vec<String>
pub fn all_action_names() -> Vec<String>
All valid action name strings, sorted alphabetically.
Generated from the same macro as from_str, guaranteeing compile-time completeness.
Sourcepub fn is_movement_or_editing(&self) -> bool
pub fn is_movement_or_editing(&self) -> bool
Check if this action is a movement or editing action that should be ignored in virtual buffers with hidden cursors.
Sourcepub fn is_editing(&self) -> bool
pub fn is_editing(&self) -> bool
Check if this action modifies buffer content (for block selection conversion). Block selections should be converted to multi-cursor before these actions.