pub struct BufferFormat { /* private fields */ }Expand description
Encoding + line-ending state for one TextBuffer.
Owns both the current and the original-at-load-time values so the save path can detect that the user changed the format and rewrite the bytes accordingly.
Implementations
Sourceimpl BufferFormat
impl BufferFormat
pub fn new(line_ending: LineEnding, encoding: Encoding) -> Self
pub fn line_ending(&self) -> LineEnding
pub fn encoding(&self) -> Encoding
pub fn original_line_ending(&self) -> LineEnding
pub fn original_encoding(&self) -> Encoding
pub fn set_line_ending(&mut self, le: LineEnding)
pub fn set_encoding(&mut self, e: Encoding)
pub fn set_default_line_ending(&mut self, le: LineEnding)
pub fn set_default_encoding(&mut self, e: Encoding)
pub fn line_ending_changed_since_load(&self) -> bool
pub fn encoding_changed_since_load(&self) -> bool