pub struct LineAlignment {
pub rows: Vec<AlignedRow>,
}Expand description
Alignment information for side-by-side views
Fields
rows: Vec<AlignedRow>Each entry maps a display row to source lines in each pane None means padding (blank line) for that pane
Implementations
Sourceimpl LineAlignment
impl LineAlignment
Sourcepub fn empty(_pane_count: usize) -> Self
pub fn empty(_pane_count: usize) -> Self
Create an empty alignment for the given number of panes
Sourcepub fn simple(line_count: usize, pane_count: usize) -> Self
pub fn simple(line_count: usize, pane_count: usize) -> Self
Create alignment from simple line-by-line mapping (no diff) Assumes both buffers have the same number of lines
Sourcepub fn from_hunks(
hunks: &[DiffHunk],
old_line_count: usize,
new_line_count: usize,
) -> Self
pub fn from_hunks( hunks: &[DiffHunk], old_line_count: usize, new_line_count: usize, ) -> Self
Create alignment from diff hunks
Sourcepub fn get_row(&self, display_row: usize) -> Option<&AlignedRow>
pub fn get_row(&self, display_row: usize) -> Option<&AlignedRow>
Get the aligned row at the given display index
Sourcepub fn next_hunk_row(&self, after_row: usize) -> Option<usize>
pub fn next_hunk_row(&self, after_row: usize) -> Option<usize>
Find the next hunk header row after the given row
Sourcepub fn prev_hunk_row(&self, before_row: usize) -> Option<usize>
pub fn prev_hunk_row(&self, before_row: usize) -> Option<usize>
Find the previous hunk header row before the given row