pub enum Encoding {
Utf8,
Utf8Bom,
Utf16Le,
Utf16Be,
Ascii,
Latin1,
Windows1252,
Windows1250,
Gb18030,
Gbk,
ShiftJis,
EucKr,
}Expand description
Supported text encodings for file I/O
The editor internally uses UTF-8 for all text processing. When loading files, content is converted from the detected encoding to UTF-8. When saving, content is converted back to the original (or user-selected) encoding.
Variants
Utf8
UTF-8 (default, most common)
Utf8Bom
UTF-8 with Byte Order Mark
Utf16Le
UTF-16 Little Endian (Windows default for Unicode files)
Utf16Be
UTF-16 Big Endian
Ascii
ASCII (7-bit, subset of UTF-8)
Latin1
Latin-1 / ISO-8859-1 (Western European)
Windows1252
Windows-1252 / CP-1252 (Windows Western European, often called “ANSI”)
Windows1250
Windows-1250 / CP-1250 (Windows Central European)
Gb18030
GB18030 (Chinese, superset of GBK)
Gbk
GBK (Chinese Simplified, subset of GB18030)
ShiftJis
Shift-JIS (Japanese)
EucKr
EUC-KR (Korean)
Implementations
Sourceimpl Encoding
impl Encoding
Sourcepub fn display_name(&self) -> &'static str
pub fn display_name(&self) -> &'static str
Get the display name for status bar
Sourcepub fn description(&self) -> &'static str
pub fn description(&self) -> &'static str
Get a longer description for UI (e.g., command palette)
Sourcepub fn to_encoding_rs(&self) -> &'static Encoding
pub fn to_encoding_rs(&self) -> &'static Encoding
Get the encoding_rs Encoding for this type
Sourcepub fn is_resynchronizable(&self) -> bool
pub fn is_resynchronizable(&self) -> bool
Returns true if this encoding supports “resynchronization” - the ability to find character boundaries when jumping into the middle of a file.
Resynchronizable encodings can be safely used with lazy/streaming file loading because you can determine character boundaries from any position.
- UTF-8: Excellent - unique bit patterns distinguish lead/continuation bytes
- ASCII/Latin-1/Windows-1252: Trivial - every byte is a character
- UTF-16: Good with 2-byte alignment - can detect surrogate pairs
- UTF-32: Good with 4-byte alignment
Non-resynchronizable encodings (legacy CJK like Shift-JIS, GB18030, GBK, Big5) have ambiguous byte sequences where a byte could be either a standalone character or part of a multi-byte sequence. You must scan from the beginning to be certain.
Sourcepub fn alignment(&self) -> Option<usize>
pub fn alignment(&self) -> Option<usize>
Returns the byte alignment required for this encoding when doing random access.
For lazy loading of large files, reads must be aligned to this boundary. Returns None if the encoding is not resynchronizable (requires full file scan).
Sourcepub fn requires_full_file_load(&self) -> bool
pub fn requires_full_file_load(&self) -> bool
Returns true if this encoding requires the entire file to be loaded for correct decoding (cannot use lazy/streaming loading).
This is the inverse of is_resynchronizable() and indicates that
the user should be warned before loading large files in this encoding.