pub struct TextPropertyManager { /* private fields */ }Expand description
Manager for text properties in a buffer
Stores and queries text properties efficiently. Properties can overlap and are sorted by start position for fast lookup.
Implementations
Sourceimpl TextPropertyManager
impl TextPropertyManager
Sourcepub fn add(&mut self, property: TextProperty)
pub fn add(&mut self, property: TextProperty)
Add a text property
Sourcepub fn get_at(&self, pos: usize) -> Vec<&TextProperty>
pub fn get_at(&self, pos: usize) -> Vec<&TextProperty>
Get all properties at a specific byte position
Sourcepub fn get_overlapping(&self, range: &Range<usize>) -> Vec<&TextProperty>
pub fn get_overlapping(&self, range: &Range<usize>) -> Vec<&TextProperty>
Get all properties overlapping a range
Sourcepub fn remove_in_range(&mut self, range: &Range<usize>)
pub fn remove_in_range(&mut self, range: &Range<usize>)
Remove all properties in a range
Sourcepub fn all(&self) -> &[TextProperty]
pub fn all(&self) -> &[TextProperty]
Get all properties
Sourcepub fn set_all(&mut self, properties: Vec<TextProperty>)
pub fn set_all(&mut self, properties: Vec<TextProperty>)
Set all properties at once (replaces existing)
Sourcepub fn from_entries(
entries: Vec<TextPropertyEntry>,
) -> (String, Self, Vec<CollectedOverlay>)
pub fn from_entries( entries: Vec<TextPropertyEntry>, ) -> (String, Self, Vec<CollectedOverlay>)
Merge properties from another source
This is useful when setting buffer content with properties. Returns the assembled text, the property manager, and any collected inline overlay specifications (with absolute byte offsets).