pub struct LineMappings {
pub char_source_bytes: Vec<Option<usize>>,
pub char_visual_cols: Vec<usize>,
pub visual_to_char: Vec<usize>,
pub total_visual_width: usize,
}Expand description
Per-line mappings that support all visual layout operations with O(1) lookups
Fields
char_source_bytes: Vec<Option<usize>>Source byte for each character (indexed by char position) Length == number of characters in processed text
char_visual_cols: Vec<usize>Visual column for each character (indexed by char position) For zero-width chars, this is the same as the previous char’s visual column
visual_to_char: Vec<usize>Character index at each visual column (indexed by visual column) For double-width chars, consecutive visual columns map to the same char Length == total visual width of line
total_visual_width: usizeTotal visual width of the line
Implementations
Sourceimpl LineMappings
impl LineMappings
Sourcepub fn source_byte_at_char(&self, char_idx: usize) -> Option<usize>
pub fn source_byte_at_char(&self, char_idx: usize) -> Option<usize>
Get source byte for a character at the given index
Sourcepub fn visual_col_at_char(&self, char_idx: usize) -> usize
pub fn visual_col_at_char(&self, char_idx: usize) -> usize
Get visual column for a character at the given index
Sourcepub fn char_at_visual_col(&self, visual_col: usize) -> usize
pub fn char_at_visual_col(&self, visual_col: usize) -> usize
Get character index at a given visual column (O(1) for mouse clicks)
Sourcepub fn source_byte_at_visual_col(&self, visual_col: usize) -> Option<usize>
pub fn source_byte_at_visual_col(&self, visual_col: usize) -> Option<usize>
Get source byte at a given visual column (O(1) for mouse clicks)
Sourcepub fn line_end_byte(&self) -> usize
pub fn line_end_byte(&self) -> usize
Get the source byte at the end of the line