Module input_parser

Module input_parser 

Server-side input parsing

Parses raw bytes from the client into crossterm events. This allows the server to handle all input parsing, keeping the client ultra-light.

Structs

InputParser
Parser state for incremental input parsing