pub struct ClientConnection {
pub data: StreamWrapper,
pub control: StreamWrapper,
}Expand description
Client connection to server
Fields
data: StreamWrapperData stream for raw byte stream
control: StreamWrapperControl stream for JSON messages
Implementations
Sourceimpl ClientConnection
impl ClientConnection
Sourcepub fn connect(paths: &SocketPaths) -> Result<Self>
pub fn connect(paths: &SocketPaths) -> Result<Self>
Connect to a server at the given socket paths
Sourcepub fn set_data_nonblocking(&self, nonblocking: bool) -> Result<()>
pub fn set_data_nonblocking(&self, nonblocking: bool) -> Result<()>
Set data socket to non-blocking mode
Sourcepub fn write_data(&self, buf: &[u8]) -> Result<()>
pub fn write_data(&self, buf: &[u8]) -> Result<()>
Write to data socket
Sourcepub fn read_control(&self) -> Result<Option<String>>
pub fn read_control(&self) -> Result<Option<String>>
Read a control message
Sourcepub fn write_control(&self, msg: &str) -> Result<()>
pub fn write_control(&self, msg: &str) -> Result<()>
Write a control message
Sourcepub fn as_raw_fds(&self) -> (RawFd, RawFd)
pub fn as_raw_fds(&self) -> (RawFd, RawFd)
Get the raw file descriptors for use with poll/select (Unix only)