pub enum ServerControl {
Hello(ServerHello),
VersionMismatch(VersionMismatch),
Pong,
SetTitle {
title: String,
},
Bell,
Quit {
reason: String,
},
Error {
message: String,
},
WaitComplete,
SetClipboard {
text: String,
use_osc52: bool,
use_system_clipboard: bool,
},
}Expand description
Control messages from server to client
Variants
Hello(ServerHello)
Handshake response
VersionMismatch(VersionMismatch)
Version mismatch error
Pong
Keepalive pong
SetTitle
Set terminal title
Bell
Ring the bell
Quit
Server is shutting down
Error
Error message
WaitComplete
Signal that a –wait operation has completed
SetClipboard
Set the system clipboard on the client side The client should use the specified methods to copy the text