Module embedded

Module embedded 

Embedded plugins support

When the embed-plugins feature is enabled, this module provides access to plugins that are compiled directly into the binary. This is useful for cargo-binstall distributions where the plugins directory would otherwise be missing.

The plugins are extracted to a temporary directory at runtime and loaded from there.

Functions

get_embedded_plugins_dir
Get the path to the embedded plugins directory.