pub struct PluginDevWorkspace {
pub plugin_file: PathBuf,
/* private fields */
}Expand description
Manages a temporary workspace for plugin development LSP support.
Fields
plugin_file: PathBufPath to the plugin source file within the workspace
Implementations
Sourceimpl PluginDevWorkspace
impl PluginDevWorkspace
Sourcepub fn create(
buffer_id: usize,
content: &str,
fresh_dts_source: &Path,
) -> Result<Self, String>
pub fn create( buffer_id: usize, content: &str, fresh_dts_source: &Path, ) -> Result<Self, String>
Create a new plugin dev workspace for the given buffer.
This creates a temp directory, copies fresh.d.ts from the source,
writes tsconfig.json, and writes the buffer content to plugin.ts.
Arguments
buffer_id- The buffer ID (used to create a unique directory)content- The current buffer contentfresh_dts_source- Path to thefresh.d.tsfile to copy