pub struct TextInputState {
pub value: String,
pub cursor: usize,
pub label: String,
pub placeholder: String,
pub focus: FocusState,
pub validate_json: bool,
}Expand description
State for a text input control
Fields
value: StringCurrent text value
cursor: usizeCursor position (character index)
label: StringLabel displayed before the input
placeholder: StringPlaceholder text when empty
focus: FocusStateFocus state
validate_json: boolIf true, validate that value is valid JSON before allowing exit
Implementations
Sourceimpl TextInputState
impl TextInputState
Sourcepub fn handle_mouse(
&mut self,
event: MouseEvent,
layout: &TextInputLayout,
) -> Option<TextInputEvent>
pub fn handle_mouse( &mut self, event: MouseEvent, layout: &TextInputLayout, ) -> Option<TextInputEvent>
Sourcepub fn handle_key(&mut self, key: KeyEvent) -> Option<TextInputEvent>
pub fn handle_key(&mut self, key: KeyEvent) -> Option<TextInputEvent>
Handle a keyboard event for this text input
Returns
Some(TextInputEvent)if the event was consumedNoneif the event was not relevant
Sourceimpl TextInputState
impl TextInputState
Sourcepub fn with_json_validation(self) -> Self
pub fn with_json_validation(self) -> Self
Set JSON validation mode
Sourcepub fn is_valid(&self) -> bool
pub fn is_valid(&self) -> bool
Check if the current value is valid (valid JSON if validate_json is set)
Sourcepub fn with_value(self, value: impl Into<String>) -> Self
pub fn with_value(self, value: impl Into<String>) -> Self
Set the initial value
Sourcepub fn with_placeholder(self, placeholder: impl Into<String>) -> Self
pub fn with_placeholder(self, placeholder: impl Into<String>) -> Self
Set the placeholder text
Sourcepub fn with_focus(self, focus: FocusState) -> Self
pub fn with_focus(self, focus: FocusState) -> Self
Set the focus state
Sourcepub fn is_enabled(&self) -> bool
pub fn is_enabled(&self) -> bool
Check if the control is enabled
Sourcepub fn insert_str(&mut self, s: &str)
pub fn insert_str(&mut self, s: &str)
Insert a string at the cursor position
Sourcepub fn delete(&mut self)
pub fn delete(&mut self)
Delete the grapheme cluster at the cursor (delete key)
Deletes the entire grapheme cluster, handling combining characters properly.
Sourcepub fn move_left(&mut self)
pub fn move_left(&mut self)
Move cursor left (to previous grapheme cluster boundary)
Uses grapheme cluster boundaries for proper handling of combining characters like Thai diacritics, emoji with modifiers, etc.
Sourcepub fn move_right(&mut self)
pub fn move_right(&mut self)
Move cursor right (to next grapheme cluster boundary)
Uses grapheme cluster boundaries for proper handling of combining characters like Thai diacritics, emoji with modifiers, etc.