Module margin

Module margin 

Structs

LineIndicator
A line indicator displayed in the gutter’s indicator column Can be used for git status, breakpoints, bookmarks, etc.
MarginAnnotation
A margin annotation for a specific line
MarginConfig
Configuration for a margin
MarginManager
Manages margins and annotations for a buffer This is similar to OverlayManager - a general-purpose primitive for margin decorations

Enums

MarginContent
Content type for a margin at a specific line
MarginPosition
Position of a margin in the editor