pub struct PopupManager { /* private fields */ }Expand description
Manager for popups - can show multiple popups with z-ordering
Implementations
Sourceimpl PopupManager
impl PopupManager
pub fn new() -> Self
Sourcepub fn show_or_replace(&mut self, popup: Popup)
pub fn show_or_replace(&mut self, popup: Popup)
Show a popup, replacing any existing popup of the same kind.
If a popup with the same PopupKind already exists in the stack,
it is replaced in-place. Otherwise the new popup is pushed on top.
Sourcepub fn get_mut(&mut self, index: usize) -> Option<&mut Popup>
pub fn get_mut(&mut self, index: usize) -> Option<&mut Popup>
Get mutable reference to popup by index
Sourcepub fn is_visible(&self) -> bool
pub fn is_visible(&self) -> bool
Check if any popups are visible
Sourcepub fn is_completion_popup(&self) -> bool
pub fn is_completion_popup(&self) -> bool
Check if the topmost popup is a completion popup (supports type-to-filter)
Sourcepub fn is_hover_popup(&self) -> bool
pub fn is_hover_popup(&self) -> bool
Check if the topmost popup is a hover popup
Sourcepub fn is_action_popup(&self) -> bool
pub fn is_action_popup(&self) -> bool
Check if the topmost popup is an action popup
Sourcepub fn dismiss_transient(&mut self) -> bool
pub fn dismiss_transient(&mut self) -> bool
Dismiss transient popups if present at the top. These popups should be dismissed when the buffer loses focus. Returns true if a popup was dismissed.