Module scroll_sync

Module scroll_sync 

Structs

ScrollSyncGroup
A group of two splits that scroll together with anchor-based synchronization
ScrollSyncManager
Manager for scroll sync groups
SyncAnchor
A sync anchor linking corresponding line positions in two buffers

Type Aliases

ScrollSyncGroupId
A unique identifier for a scroll sync group