pub struct SoftBreakManager { /* private fields */ }Expand description
Manages soft break points for a buffer
Implementations
Sourceimpl SoftBreakManager
impl SoftBreakManager
Sourcepub fn add(
&mut self,
marker_list: &mut MarkerList,
namespace: OverlayNamespace,
position: usize,
indent: u16,
)
pub fn add( &mut self, marker_list: &mut MarkerList, namespace: OverlayNamespace, position: usize, indent: u16, )
Add a soft break point
Sourcepub fn clear_namespace(
&mut self,
namespace: &OverlayNamespace,
marker_list: &mut MarkerList,
)
pub fn clear_namespace( &mut self, namespace: &OverlayNamespace, marker_list: &mut MarkerList, )
Remove all soft breaks in a namespace
Sourcepub fn remove_in_range(
&mut self,
start: usize,
end: usize,
marker_list: &mut MarkerList,
)
pub fn remove_in_range( &mut self, start: usize, end: usize, marker_list: &mut MarkerList, )
Remove all soft breaks that fall within a byte range and clean up their markers
Sourcepub fn clear(&mut self, marker_list: &mut MarkerList)
pub fn clear(&mut self, marker_list: &mut MarkerList)
Clear all soft breaks and their markers
Sourcepub fn query_viewport(
&self,
start: usize,
end: usize,
marker_list: &MarkerList,
) -> Vec<(usize, u16)>
pub fn query_viewport( &self, start: usize, end: usize, marker_list: &MarkerList, ) -> Vec<(usize, u16)>
Query soft breaks that fall within a viewport range.
Returns sorted (position, indent) pairs for efficient token processing.