pub struct ViewLine {
pub text: String,
pub source_start_byte: Option<usize>,
pub char_source_bytes: Vec<Option<usize>>,
pub char_styles: Vec<Option<ViewTokenStyle>>,
pub char_visual_cols: Vec<usize>,
pub visual_to_char: Vec<usize>,
pub tab_starts: HashSet<usize>,
pub line_start: LineStart,
pub ends_with_newline: bool,
}Expand description
A display line built from tokens, preserving token-level information
Fields
text: StringThe display text for this line (tabs expanded to spaces, etc.)
source_start_byte: Option<usize>Absolute source byte offset of the start of this line (if it has one)
char_source_bytes: Vec<Option<usize>>Source byte offset for each character Length == text.chars().count()
char_styles: Vec<Option<ViewTokenStyle>>Style for each character (from token styles)
char_visual_cols: Vec<usize>Visual column where each character starts
visual_to_char: Vec<usize>Character index at each visual column (for O(1) mouse clicks) For double-width chars, consecutive visual columns map to the same char index Length == total visual width of line
tab_starts: HashSet<usize>Positions that are the start of a tab expansion
line_start: LineStartHow this line started (what kind of token/boundary preceded it)
ends_with_newline: boolWhether this line ends with a newline character
Implementations
Sourceimpl ViewLine
impl ViewLine
Sourcepub fn source_byte_at_char(&self, char_idx: usize) -> Option<usize>
pub fn source_byte_at_char(&self, char_idx: usize) -> Option<usize>
Get source byte at a given character index (O(1))
Sourcepub fn char_at_visual_col(&self, visual_col: usize) -> usize
pub fn char_at_visual_col(&self, visual_col: usize) -> usize
Get character index at a given visual column (O(1))
Sourcepub fn source_byte_at_visual_col(&self, visual_col: usize) -> Option<usize>
pub fn source_byte_at_visual_col(&self, visual_col: usize) -> Option<usize>
Get source byte at a given visual column (O(1) for mouse clicks)
Sourcepub fn visual_col_at_char(&self, char_idx: usize) -> usize
pub fn visual_col_at_char(&self, char_idx: usize) -> usize
Get the visual column for a character at the given index
Sourcepub fn visual_width(&self) -> usize
pub fn visual_width(&self) -> usize
Total visual width of this line