pub trait MenuExt {
// Required methods
fn match_id(&self) -> &str;
fn expand_dynamic_items(&mut self, themes_dir: &Path);
}Expand description
Extension trait for Menu with editor-specific functionality
Required Methods
Sourcefn match_id(&self) -> &str
fn match_id(&self) -> &str
Get the identifier for matching (id if set, otherwise label). This is used for keybinding matching and should be stable across translations.
Sourcefn expand_dynamic_items(&mut self, themes_dir: &Path)
fn expand_dynamic_items(&mut self, themes_dir: &Path)
Expand all DynamicSubmenu items in this menu to regular Submenu items This should be called before the menu is used for rendering/navigation