Module multi_cursor

Module multi_cursor 

Multi-cursor operations for adding cursors at various positions

Enums

AddCursorResult
Result of attempting to add a cursor

Functions

add_cursor_above
Add a cursor above the primary cursor at the same column
add_cursor_at_next_match
Add a cursor at the next occurrence of the selected text If no selection, selects the entire word at cursor position first
add_cursor_below
Add a cursor below the primary cursor at the same column