Multi-cursor operations for adding cursors at various positions
Enums
- AddCursor
Result - Result of attempting to add a cursor
Functions
- add_
cursor_ above - Add a cursor above the primary cursor at the same column
- add_
cursor_ at_ next_ match - Add a cursor at the next occurrence of the selected text If no selection, selects the entire word at cursor position first
- add_
cursor_ below - Add a cursor below the primary cursor at the same column