AsyncMessage

Enum AsyncMessage 

pub enum AsyncMessage {
Show 40 variants LspDiagnostics { uri: String, diagnostics: Vec<Diagnostic>, server_name: String, }, LspInitialized { language: String, server_name: String, capabilities: ServerCapabilitySummary, }, LspError { language: String, error: String, stderr_log_path: Option<PathBuf>, }, LspCompletion { request_id: u64, items: Vec<CompletionItem>, }, LspGotoDefinition { request_id: u64, locations: Vec<Location>, }, LspRename { request_id: u64, result: Result<WorkspaceEdit, String>, }, LspHover { request_id: u64, contents: String, is_markdown: bool, range: Option<((u32, u32), (u32, u32))>, }, LspReferences { request_id: u64, locations: Vec<Location>, }, LspSignatureHelp { request_id: u64, signature_help: Option<SignatureHelp>, }, LspCodeActions { request_id: u64, actions: Vec<CodeActionOrCommand>, }, LspCompletionResolved { request_id: u64, item: Result<CompletionItem, String>, }, LspFormatting { request_id: u64, uri: String, edits: Vec<TextEdit>, }, LspPrepareRename { request_id: u64, result: Result<Value, String>, }, LspPulledDiagnostics { request_id: u64, uri: String, result_id: Option<String>, diagnostics: Vec<Diagnostic>, unchanged: bool, }, LspInlayHints { request_id: u64, uri: String, hints: Vec<InlayHint>, }, LspFoldingRanges { request_id: u64, uri: String, ranges: Vec<FoldingRange>, }, LspSemanticTokens { request_id: u64, uri: String, response: LspSemanticTokensResponse, }, LspServerQuiescent { language: String, }, LspDiagnosticRefresh { language: String, }, FileChanged { path: String, }, GitStatusChanged { status: String, }, FileExplorerInitialized(FileTreeView), FileExplorerToggleNode(NodeId), FileExplorerRefreshNode(NodeId), FileExplorerExpandedToPath(FileTreeView), Plugin(PluginAsyncMessage), FileOpenDirectoryLoaded(Result<Vec<DirEntry>>), FileOpenShortcutsLoaded(Vec<NavigationShortcut>), TerminalOutput { terminal_id: TerminalId, }, TerminalExited { terminal_id: TerminalId, }, LspProgress { language: String, token: String, value: LspProgressValue, }, LspWindowMessage { language: String, message_type: LspMessageType, message: String, }, LspLogMessage { language: String, message_type: LspMessageType, message: String, }, LspApplyEdit { edit: WorkspaceEdit, label: Option<String>, }, LspCodeActionResolved { request_id: u64, action: Result<CodeAction, String>, }, LspServerRequest { language: String, server_command: String, method: String, params: Option<Value>, }, PluginLspResponse { language: String, request_id: u64, result: Result<Value, String>, }, PluginProcessOutput { process_id: u64, stdout: String, stderr: String, exit_code: i32, }, LspStatusUpdate { language: String, server_name: String, status: LspServerStatus, message: Option<String>, }, GrammarRegistryBuilt { registry: Arc<GrammarRegistry>, callback_ids: Vec<JsCallbackId>, },
}
Messages sent from async tasks to the synchronous main loop

Variants



LspDiagnostics

LSP diagnostics received for a file

Fields

diagnostics: Vec<Diagnostic>
server_name: String

Name of the server that sent these diagnostics (for per-server tracking)



LspInitialized

LSP server initialized successfully

Fields

language: String
server_name: String

Name of the specific server (for per-server capability tracking)

capabilities: ServerCapabilitySummary

Capabilities reported by this server



LspError

LSP server crashed or failed

Fields

language: String
error: String
stderr_log_path: Option<PathBuf>

Path to the stderr log file for this LSP session



LspCompletion

LSP completion response

Fields

request_id: u64


LspGotoDefinition

LSP go-to-definition response

Fields

request_id: u64
locations: Vec<Location>


LspRename

LSP rename response

Fields

request_id: u64


LspHover

LSP hover response

Fields

request_id: u64
contents: String

Hover contents as a single string (joined if multiple parts)

is_markdown: bool

Whether the content is markdown (true) or plaintext (false)

range: Option<((u32, u32), (u32, u32))>

Optional range of the symbol that was hovered over (LSP line/character positions) Used to highlight the hovered symbol



LspReferences

LSP find references response

Fields

request_id: u64
locations: Vec<Location>


LspSignatureHelp

LSP signature help response

Fields

request_id: u64
signature_help: Option<SignatureHelp>


LspCodeActions

LSP code actions response

Fields

request_id: u64


LspCompletionResolved

LSP completionItem/resolve response

Fields

request_id: u64


LspFormatting

LSP textDocument/formatting response

Fields

request_id: u64
edits: Vec<TextEdit>


LspPrepareRename

LSP textDocument/prepareRename response

Fields

request_id: u64


LspPulledDiagnostics

LSP pulled diagnostics response (textDocument/diagnostic)

Fields

request_id: u64
result_id: Option<String>

New result_id for incremental updates (None if server doesn’t support)

diagnostics: Vec<Diagnostic>

Diagnostics (empty if unchanged)

unchanged: bool

True if diagnostics haven’t changed since previous_result_id



LspInlayHints

LSP inlay hints response (textDocument/inlayHint)

Fields

request_id: u64
hints: Vec<InlayHint>

Inlay hints for the requested range



LspFoldingRanges

LSP folding ranges response (textDocument/foldingRange)

Fields

request_id: u64


LspSemanticTokens

LSP semantic tokens response (full, full/delta, or range)

Fields

request_id: u64


LspServerQuiescent

LSP server status became quiescent (project fully loaded) This is a rust-analyzer specific notification (experimental/serverStatus)

Fields

language: String


LspDiagnosticRefresh

LSP server requests diagnostic refresh (workspace/diagnostic/refresh) Client should re-pull diagnostics for all open documents

Fields

language: String


FileChanged

File changed externally (future: file watching)

Fields

path: String


GitStatusChanged

Git status updated (future: git integration)

Fields

status: String


FileExplorerInitialized(FileTreeView)

File explorer initialized with tree view



FileExplorerToggleNode(NodeId)

File explorer node toggle completed



FileExplorerRefreshNode(NodeId)

File explorer node refresh completed



FileExplorerExpandedToPath(FileTreeView)

File explorer expand to path completed Contains the updated FileTreeView with the path expanded and selected



Plugin(PluginAsyncMessage)

Plugin-related async messages



FileOpenDirectoryLoaded(Result<Vec<DirEntry>>)

File open dialog: directory listing completed



FileOpenShortcutsLoaded(Vec<NavigationShortcut>)

File open dialog: async shortcuts (Windows drive letters) loaded



TerminalOutput

Terminal output received (triggers redraw)

Fields

terminal_id: TerminalId


TerminalExited

Terminal process exited

Fields

terminal_id: TerminalId


LspProgress

LSP progress notification ($/progress)

Fields

language: String
token: String


LspWindowMessage

LSP window message (window/showMessage)

Fields

language: String
message_type: LspMessageType
message: String


LspLogMessage

LSP log message (window/logMessage)

Fields

language: String
message_type: LspMessageType
message: String


LspApplyEdit

LSP workspace/applyEdit (server -> client request) Server asks client to apply a workspace edit (during executeCommand, etc.)

Fields



LspCodeActionResolved

LSP codeAction/resolve response

Fields

request_id: u64


LspServerRequest

LSP server request (server -> client) Used for custom/extension methods that plugins can handle

Fields

language: String
server_command: String
method: String
params: Option<Value>


PluginLspResponse

Response for a plugin-initiated LSP request

Fields

language: String
request_id: u64


PluginProcessOutput

Plugin process completed with output

Fields

process_id: u64

Unique ID for this process (to match with callback)

stdout: String

Standard output

stderr: String

Standard error

exit_code: i32

Exit code



LspStatusUpdate

LSP server status update (progress, messages, etc.)

Fields

language: String
server_name: String

Name of the specific server (for multi-server status tracking)

message: Option<String>


GrammarRegistryBuilt

Background grammar build completed — swap in the new registry. callback_ids contains plugin callbacks to resolve (empty for the initial startup build).

Fields

callback_ids: Vec<JsCallbackId>