pub struct AgentChannel { /* private fields */ }Expand description
Communication channel with the remote agent
Implementations
Sourceimpl AgentChannel
impl AgentChannel
Sourcepub fn new(reader: BufReader<ChildStdout>, writer: ChildStdin) -> Self
pub fn new(reader: BufReader<ChildStdout>, writer: ChildStdin) -> Self
Create a new channel from async read/write handles
Must be called from within a Tokio runtime context.
Sourcepub fn with_capacity(
reader: BufReader<ChildStdout>,
writer: ChildStdin,
data_channel_capacity: usize,
) -> Self
pub fn with_capacity( reader: BufReader<ChildStdout>, writer: ChildStdin, data_channel_capacity: usize, ) -> Self
Create a new channel with a custom data channel capacity.
Lower capacity makes channel overflow more likely if try_send is used,
which is useful for stress-testing backpressure handling.
Sourcepub fn is_connected(&self) -> bool
pub fn is_connected(&self) -> bool
Check if the channel is connected
Sourcepub async fn request(
&self,
method: &str,
params: Value,
) -> Result<Value, ChannelError>
pub async fn request( &self, method: &str, params: Value, ) -> Result<Value, ChannelError>
Send a request and wait for the final result (ignoring streaming data)
Sourcepub async fn request_streaming(
&self,
method: &str,
params: Value,
) -> Result<(Receiver<Value>, Receiver<Result<Value, String>>), ChannelError>
pub async fn request_streaming( &self, method: &str, params: Value, ) -> Result<(Receiver<Value>, Receiver<Result<Value, String>>), ChannelError>
Send a request that may stream data
Sourcepub fn request_blocking(
&self,
method: &str,
params: Value,
) -> Result<Value, ChannelError>
pub fn request_blocking( &self, method: &str, params: Value, ) -> Result<Value, ChannelError>
Send a request synchronously (blocking)
This can be called from outside the Tokio runtime context.
Sourcepub async fn request_with_data(
&self,
method: &str,
params: Value,
) -> Result<(Vec<Value>, Value), ChannelError>
pub async fn request_with_data( &self, method: &str, params: Value, ) -> Result<(Vec<Value>, Value), ChannelError>
Send a request and collect all streaming data along with the final result