pub struct LspServerConfig {
pub command: String,
pub args: Vec<String>,
pub enabled: bool,
pub auto_start: bool,
pub process_limits: ProcessLimits,
pub initialization_options: Option<Value>,
}Expand description
LSP server configuration
Fields
command: StringCommand to spawn the server. Required when enabled=true, ignored when enabled=false.
args: Vec<String>Arguments to pass to the server
enabled: boolWhether the server is enabled
auto_start: boolWhether to auto-start this LSP server when opening matching files If false (default), the server must be started manually via command palette
process_limits: ProcessLimitsProcess resource limits (memory and CPU)
initialization_options: Option<Value>Custom initialization options to send to the server
These are passed in the initializationOptions field of the LSP Initialize request
Implementations
Sourceimpl LspServerConfig
impl LspServerConfig
Sourcepub fn merge_with_defaults(self, defaults: &LspServerConfig) -> LspServerConfig
pub fn merge_with_defaults(self, defaults: &LspServerConfig) -> LspServerConfig
Merge this config with defaults, using default values for empty/unset fields.
This is used when loading configs where fields like command may be empty
(serde’s default) because they weren’t specified in the user’s config file.