pub struct MenuState {
pub active_menu: Option<usize>,
pub highlighted_item: Option<usize>,
pub submenu_path: Vec<usize>,
pub plugin_menus: Vec<Menu>,
pub context: MenuContext,
}Expand description
Menu bar state (tracks which menu is open and which item is highlighted)
Fields
Index of the currently open menu (None if menu bar is closed)
highlighted_item: Option<usize>Index of the highlighted item within the active menu or current submenu
Path of indices into nested submenus (empty = at top level menu) Each element is the index of the submenu item that was opened
Runtime menu additions from plugins
context: MenuContextContext containing named boolean states for conditions and checkboxes
Implementations
Sourceimpl MenuState
impl MenuState
pub fn new() -> Self
Open a menu by index
Close the currently open menu (and all submenus)
Navigate to the next menu (right) - only at top level
Navigate to the previous menu (left) - only at top level
Check if we’re currently in a submenu
Get the current submenu depth (0 = top level menu)
Open a submenu at the current highlighted item Returns true if a submenu was opened, false if the item wasn’t a submenu
Close the current submenu and go back to parent Returns true if a submenu was closed, false if already at top level
Sourcepub fn get_current_items<'a>(
&self,
menus: &'a [Menu],
active_idx: usize,
) -> Option<&'a [MenuItem]>
pub fn get_current_items<'a>( &self, menus: &'a [Menu], active_idx: usize, ) -> Option<&'a [MenuItem]>
Get the menu items at the current submenu level
Sourcepub fn get_current_items_cloned(&self, menu: &Menu) -> Option<Vec<MenuItem>>
pub fn get_current_items_cloned(&self, menu: &Menu) -> Option<Vec<MenuItem>>
Get owned vec of current items (for use when Menu is cloned) DynamicSubmenus are expanded to regular Submenus
Sourcepub fn next_item(&mut self, menu: &Menu)
pub fn next_item(&mut self, menu: &Menu)
Navigate to the next item in the current menu/submenu (down)
Sourcepub fn prev_item(&mut self, menu: &Menu)
pub fn prev_item(&mut self, menu: &Menu)
Navigate to the previous item in the current menu/submenu (up)
Sourcepub fn get_highlighted_action(
&self,
menus: &[Menu],
) -> Option<(String, HashMap<String, Value>)>
pub fn get_highlighted_action( &self, menus: &[Menu], ) -> Option<(String, HashMap<String, Value>)>
Get the currently highlighted action (if any) This navigates through the submenu path to find the currently highlighted item
Check if the currently highlighted item is a submenu
Get the menu index at a given x position in the menu bar Returns the menu index if the click is on a menu label